==> rhpam-7.10.1-sources.zip: rhba-7.10.1.GA-src/org.kie.workbench-kie-wb-common-7.48.0.Final-7.10.1/kie-wb-common-forms/kie-wb-common-dynamic-forms/kie-wb-common-dynamic-forms-backend/src/main/java/org/kie/workbench/common/forms/dynamic/backend/server/context/generation/dynamic/impl/marshalling/time/DateMultipleInputFieldValueMarshaller.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.dynamic.backend.server.context.generation.dynamic.impl.marshalling.time;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

import javax.enterprise.context.Dependent;

import org.kie.workbench.common.forms.dynamic.backend.server.context.generation.dynamic.impl.marshalling.FieldValueMarshaller;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.DateMultipleInputFieldDefinition;

@Dependent
public class DateMultipleInputFieldValueMarshaller extends AbstractDateMultipleFieldValueMarshaller<DateMultipleInputFieldDefinition> {

    @Override
    public Class<DateMultipleInputFieldDefinition> getSupportedField() {
        return DateMultipleInputFieldDefinition.class;
    }

    @Override
    public Supplier<FieldValueMarshaller<List<?>, List<Date>, DateMultipleInputFieldDefinition>> newInstanceSupplier() {
        return DateMultipleInputFieldValueMarshaller::new;
    }
}

==> rhpam-7.13.1-sources.zip: rhba-7.13.1.GA-src/org.kie.workbench-kie-wb-common-7.67.0.Final-7.13.1/kie-wb-common-forms/kie-wb-common-dynamic-forms/kie-wb-common-dynamic-forms-backend/src/main/java/org/kie/workbench/common/forms/dynamic/backend/server/context/generation/dynamic/impl/marshalling/time/DateMultipleInputFieldValueMarshaller.java <==
/*
 * Copyright 2018 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.dynamic.backend.server.context.generation.dynamic.impl.marshalling.time;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

import javax.enterprise.context.Dependent;

import org.kie.workbench.common.forms.dynamic.backend.server.context.generation.dynamic.impl.marshalling.FieldValueMarshaller;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.lists.input.impl.DateMultipleInputFieldDefinition;

@Dependent
public class DateMultipleInputFieldValueMarshaller extends AbstractDateMultipleFieldValueMarshaller<DateMultipleInputFieldDefinition> {

    @Override
    public Class<DateMultipleInputFieldDefinition> getSupportedField() {
        return DateMultipleInputFieldDefinition.class;
    }

    @Override
    public Supplier<FieldValueMarshaller<List, List<Date>, DateMultipleInputFieldDefinition>> newInstanceSupplier() {
        return DateMultipleInputFieldValueMarshaller::new;
    }
}
